#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DEINTERLEAVE_SECOND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DEINTERLEAVE_SECOND_HPP_INCLUDED

#include <boost/simd/swar/include/functions/deinterleave_second.hpp>

#endif
